pub struct IncidentBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> IncidentBuilder<S>
impl<S: State> IncidentBuilder<S>
Sourcepub fn build(self) -> Incidentwhere
S: IsComplete,
pub fn build(self) -> Incidentwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn id(self, value: IncidentId) -> IncidentBuilder<SetId<S>>where
S::Id: IsUnset,
pub fn id(self, value: IncidentId) -> IncidentBuilder<SetId<S>>where
S::Id: IsUnset,
Required.
Id retained from source records for staff review, safety gates, and workflow joins.
Sourcepub fn location_id(self, value: LocationId) -> IncidentBuilder<SetLocationId<S>>where
S::LocationId: IsUnset,
pub fn location_id(self, value: LocationId) -> IncidentBuilder<SetLocationId<S>>where
S::LocationId: IsUnset,
Required.
Location id retained from source records for staff review, safety gates, and workflow joins.
Sourcepub fn primary_subject(
self,
value: IncidentSubject,
) -> IncidentBuilder<SetPrimarySubject<S>>where
S::PrimarySubject: IsUnset,
pub fn primary_subject(
self,
value: IncidentSubject,
) -> IncidentBuilder<SetPrimarySubject<S>>where
S::PrimarySubject: IsUnset,
Required.
Primary subject retained from source records for staff review, safety gates, and workflow joins.
Sourcepub fn category(self, value: Category) -> IncidentBuilder<SetCategory<S>>where
S::Category: IsUnset,
pub fn category(self, value: Category) -> IncidentBuilder<SetCategory<S>>where
S::Category: IsUnset,
Required.
Category retained from source records for staff review, safety gates, and workflow joins.
Sourcepub fn severity(self, value: Severity) -> IncidentBuilder<SetSeverity<S>>where
S::Severity: IsUnset,
pub fn severity(self, value: Severity) -> IncidentBuilder<SetSeverity<S>>where
S::Severity: IsUnset,
Required.
Severity retained from source records for staff review, safety gates, and workflow joins.
Sourcepub fn status(self, value: Status) -> IncidentBuilder<SetStatus<S>>where
S::Status: IsUnset,
pub fn status(self, value: Status) -> IncidentBuilder<SetStatus<S>>where
S::Status: IsUnset,
Required.
Status retained from source records for staff review, safety gates, and workflow joins.
Sourcepub fn reported_by(self, value: ActorRef) -> IncidentBuilder<SetReportedBy<S>>where
S::ReportedBy: IsUnset,
pub fn reported_by(self, value: ActorRef) -> IncidentBuilder<SetReportedBy<S>>where
S::ReportedBy: IsUnset,
Required.
Reported by retained from source records for staff review, safety gates, and workflow joins.
Sourcepub fn reported_at(
self,
value: DateTime<Utc>,
) -> IncidentBuilder<SetReportedAt<S>>where
S::ReportedAt: IsUnset,
pub fn reported_at(
self,
value: DateTime<Utc>,
) -> IncidentBuilder<SetReportedAt<S>>where
S::ReportedAt: IsUnset,
Required.
Reported at retained from source records for staff review, safety gates, and workflow joins.
Sourcepub fn summary(self, value: Summary) -> IncidentBuilder<SetSummary<S>>where
S::Summary: IsUnset,
pub fn summary(self, value: Summary) -> IncidentBuilder<SetSummary<S>>where
S::Summary: IsUnset,
Required.
Summary retained from source records for staff review, safety gates, and workflow joins.