PetBuilder

Struct PetBuilder 

pub struct PetBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> PetBuilder<S>

pub fn build(self) -> Pet
where S: IsComplete,

Finish building and return the requested object

pub fn id(self, value: PetId) -> PetBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

Source-backed id carried by this normalized pet-resort entity.

pub fn customer_id(self, value: CustomerId) -> PetBuilder<SetCustomerId<S>>
where S::CustomerId: IsUnset,

Required.

Source-backed customer ID carried by this normalized pet-resort entity.

pub fn name(self, value: Name) -> PetBuilder<SetName<S>>
where S::Name: IsUnset,

Required.

Contact or display name used by staff.

pub fn species(self, value: Species) -> PetBuilder<SetSpecies<S>>
where S::Species: IsUnset,

Required.

Source-backed species carried by this normalized pet-resort entity.

pub fn birth_date(self, value: NaiveDate) -> PetBuilder<SetBirthDate<S>>
where S::BirthDate: IsUnset,

Optional (Some / Option setters). Source-backed birth date carried by this normalized pet-resort entity.

pub fn maybe_birth_date( self, value: Option<NaiveDate>, ) -> PetBuilder<SetBirthDate<S>>
where S::BirthDate: IsUnset,

Optional (Some / Option setters). Source-backed birth date carried by this normalized pet-resort entity.

pub fn sex(self, value: Sex) -> PetBuilder<SetSex<S>>
where S::Sex: IsUnset,

Optional (Some / Option setters). Source-backed sex carried by this normalized pet-resort entity.

pub fn maybe_sex(self, value: Option<Sex>) -> PetBuilder<SetSex<S>>
where S::Sex: IsUnset,

Optional (Some / Option setters). Source-backed sex carried by this normalized pet-resort entity.

pub fn spay_neuter_status( self, value: SpayNeuterStatus, ) -> PetBuilder<SetSpayNeuterStatus<S>>
where S::SpayNeuterStatus: IsUnset,

Required.

Source-backed spay neuter status carried by this normalized pet-resort entity.

pub fn temperament( self, value: TemperamentProfile, ) -> PetBuilder<SetTemperament<S>>
where S::Temperament: IsUnset,

Optional (Some / Option setters). Default: <TemperamentProfile as Default>::default().

Source-backed temperament carried by this normalized pet-resort entity.

pub fn maybe_temperament( self, value: Option<TemperamentProfile>, ) -> PetBuilder<SetTemperament<S>>
where S::Temperament: IsUnset,

Optional (Some / Option setters). Default: <TemperamentProfile as Default>::default().

Source-backed temperament carried by this normalized pet-resort entity.

pub fn care_profile(self, value: CareProfile) -> PetBuilder<SetCareProfile<S>>
where S::CareProfile: IsUnset,

Optional (Some / Option setters). Default: <CareProfile as Default>::default().

Source-backed care profile carried by this normalized pet-resort entity.

pub fn maybe_care_profile( self, value: Option<CareProfile>, ) -> PetBuilder<SetCareProfile<S>>
where S::CareProfile: IsUnset,

Optional (Some / Option setters). Default: <CareProfile as Default>::default().

Source-backed care profile carried by this normalized pet-resort entity.