ReservationBuilder

Struct ReservationBuilder 

pub struct ReservationBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ReservationBuilder<S>

pub fn build(self) -> Reservation
where S: IsComplete,

Finish building and return the requested object

pub fn id(self, value: Id) -> ReservationBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

Source-backed id carried by this normalized pet-resort entity.

pub fn location_id( self, value: LocationId, ) -> ReservationBuilder<SetLocationId<S>>
where S::LocationId: IsUnset,

Required.

Source-backed location ID carried by this normalized pet-resort entity.

pub fn customer_id( self, value: CustomerId, ) -> ReservationBuilder<SetCustomerId<S>>
where S::CustomerId: IsUnset,

Required.

Source-backed customer ID carried by this normalized pet-resort entity.

pub fn pet_ids(self, value: Vec<PetId>) -> ReservationBuilder<SetPetIds<S>>
where S::PetIds: IsUnset,

Required.

Source-backed pet IDs carried by this normalized pet-resort entity.

pub fn service(self, value: ServiceKind) -> ReservationBuilder<SetService<S>>
where S::Service: IsUnset,

Required.

Requested service that drives scheduling and labor estimates.

pub fn status(self, value: Status) -> ReservationBuilder<SetStatus<S>>
where S::Status: IsUnset,

Required.

Source-backed status carried by this normalized pet-resort entity.

pub fn starts_at( self, value: DateTime<Utc>, ) -> ReservationBuilder<SetStartsAt<S>>
where S::StartsAt: IsUnset,

Required.

Source-backed starts at carried by this normalized pet-resort entity.

pub fn ends_at(self, value: DateTime<Utc>) -> ReservationBuilder<SetEndsAt<S>>
where S::EndsAt: IsUnset,

Required.

Source-backed ends at carried by this normalized pet-resort entity.

pub fn deposit(self, value: Deposit) -> ReservationBuilder<SetDeposit<S>>
where S::Deposit: IsUnset,

Optional (Some / Option setters). Source-backed deposit carried by this normalized pet-resort entity.

pub fn maybe_deposit( self, value: Option<Deposit>, ) -> ReservationBuilder<SetDeposit<S>>
where S::Deposit: IsUnset,

Optional (Some / Option setters). Source-backed deposit carried by this normalized pet-resort entity.

pub fn source(self, value: Source) -> ReservationBuilder<SetSource<S>>
where S::Source: IsUnset,

Required.

Source-backed source carried by this normalized pet-resort entity.

pub fn requested_add_ons( self, value: Vec<AddOn>, ) -> ReservationBuilder<SetRequestedAddOns<S>>
where S::RequestedAddOns: IsUnset,

Optional (Some / Option setters). Default: <Vec<AddOn> as Default>::default().

Source-backed requested add ons carried by this normalized pet-resort entity.

pub fn maybe_requested_add_ons( self, value: Option<Vec<AddOn>>, ) -> ReservationBuilder<SetRequestedAddOns<S>>
where S::RequestedAddOns: IsUnset,

Optional (Some / Option setters). Default: <Vec<AddOn> as Default>::default().

Source-backed requested add ons carried by this normalized pet-resort entity.

pub fn hard_stops( self, value: Vec<HardStop>, ) -> ReservationBuilder<SetHardStops<S>>
where S::HardStops: IsUnset,

Optional (Some / Option setters). Default: <Vec<HardStop> as Default>::default().

Source-backed hard stops carried by this normalized pet-resort entity.

pub fn maybe_hard_stops( self, value: Option<Vec<HardStop>>, ) -> ReservationBuilder<SetHardStops<S>>
where S::HardStops: IsUnset,

Optional (Some / Option setters). Default: <Vec<HardStop> as Default>::default().

Source-backed hard stops carried by this normalized pet-resort entity.