TemperamentProfileBuilder

Struct TemperamentProfileBuilder 

pub struct TemperamentProfileBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> TemperamentProfileBuilder<S>

pub fn build(self) -> TemperamentProfile
where S: IsComplete,

Finish building and return the requested object

pub fn group_play_observation( self, value: GroupPlayObservation, ) -> TemperamentProfileBuilder<SetGroupPlayObservation<S>>
where S::GroupPlayObservation: IsUnset,

Optional (Some / Option setters). Default: <temperament::GroupPlayObservation as Default>::default().

Source-backed group play observation carried by this normalized pet-resort entity.

pub fn maybe_group_play_observation( self, value: Option<GroupPlayObservation>, ) -> TemperamentProfileBuilder<SetGroupPlayObservation<S>>
where S::GroupPlayObservation: IsUnset,

Optional (Some / Option setters). Default: <temperament::GroupPlayObservation as Default>::default().

Source-backed group play observation carried by this normalized pet-resort entity.

pub fn people_orientation( self, value: PeopleOrientation, ) -> TemperamentProfileBuilder<SetPeopleOrientation<S>>
where S::PeopleOrientation: IsUnset,

Optional (Some / Option setters). Default: <temperament::PeopleOrientation as Default>::default().

Source-backed people orientation carried by this normalized pet-resort entity.

pub fn maybe_people_orientation( self, value: Option<PeopleOrientation>, ) -> TemperamentProfileBuilder<SetPeopleOrientation<S>>
where S::PeopleOrientation: IsUnset,

Optional (Some / Option setters). Default: <temperament::PeopleOrientation as Default>::default().

Source-backed people orientation carried by this normalized pet-resort entity.

pub fn rating(self, value: Rating) -> TemperamentProfileBuilder<SetRating<S>>
where S::Rating: IsUnset,

Optional (Some / Option setters). Default: <temperament::Rating as Default>::default().

Source-backed rating carried by this normalized pet-resort entity.

pub fn maybe_rating( self, value: Option<Rating>, ) -> TemperamentProfileBuilder<SetRating<S>>
where S::Rating: IsUnset,

Optional (Some / Option setters). Default: <temperament::Rating as Default>::default().

Source-backed rating carried by this normalized pet-resort entity.

pub fn behavior_observations( self, value: Vec<BehaviorObservation>, ) -> TemperamentProfileBuilder<SetBehaviorObservations<S>>
where S::BehaviorObservations: IsUnset,

Optional (Some / Option setters). Default: <Vec<temperament::BehaviorObservation> as Default>::default().

Source-backed behavior observations carried by this normalized pet-resort entity.

pub fn maybe_behavior_observations( self, value: Option<Vec<BehaviorObservation>>, ) -> TemperamentProfileBuilder<SetBehaviorObservations<S>>
where S::BehaviorObservations: IsUnset,

Optional (Some / Option setters). Default: <Vec<temperament::BehaviorObservation> as Default>::default().

Source-backed behavior observations carried by this normalized pet-resort entity.

pub fn staff_notes( self, value: Vec<StaffNote>, ) -> TemperamentProfileBuilder<SetStaffNotes<S>>
where S::StaffNotes: IsUnset,

Optional (Some / Option setters). Default: <Vec<temperament::StaffNote> as Default>::default().

Source-backed staff notes carried by this normalized pet-resort entity.

pub fn maybe_staff_notes( self, value: Option<Vec<StaffNote>>, ) -> TemperamentProfileBuilder<SetStaffNotes<S>>
where S::StaffNotes: IsUnset,

Optional (Some / Option setters). Default: <Vec<temperament::StaffNote> as Default>::default().

Source-backed staff notes carried by this normalized pet-resort entity.