pub struct Document {Show 13 fields
pub id: DocumentId,
pub location_id: LocationId,
pub subject: DocumentSubject,
pub classification: Classification,
pub source: Source,
pub uploaded_by_actor: ActorRef,
pub uploaded_at: DateTime<Utc>,
pub original_file: OriginalFile,
pub storage_ref: StorageRef,
pub virus_scan_status: VirusScanStatus,
pub pii_redaction_status: PiiRedactionStatus,
pub verification_status: Status,
pub audit_refs: Vec<EventId>,
}Expand description
Document record tying storage, classification, source, scan, redaction, and review status together.
Fields
id: DocumentIdSource-backed id carried by this normalized pet-resort entity.
location_id: LocationIdSource-backed location ID carried by this normalized pet-resort entity.
subject: DocumentSubjectSource-backed subject carried by this normalized pet-resort entity.
classification: ClassificationSource-backed classification carried by this normalized pet-resort entity.
source: SourceSource-backed source carried by this normalized pet-resort entity.
uploaded_by_actor: ActorRefSource-backed uploaded by actor carried by this normalized pet-resort entity.
uploaded_at: DateTime<Utc>Source-backed uploaded at carried by this normalized pet-resort entity.
original_file: OriginalFileSource-backed original file carried by this normalized pet-resort entity.
storage_ref: StorageRefSource-backed storage ref carried by this normalized pet-resort entity.
virus_scan_status: VirusScanStatusSource-backed virus scan status carried by this normalized pet-resort entity.
pii_redaction_status: PiiRedactionStatusSource-backed pii redaction status carried by this normalized pet-resort entity.
verification_status: StatusSource-backed verification status carried by this normalized pet-resort entity.
audit_refs: Vec<EventId>Source-backed audit refs carried by this normalized pet-resort entity.