pub struct DocumentBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> DocumentBuilder<S>
impl<S: State> DocumentBuilder<S>
Sourcepub fn build(self) -> Documentwhere
S: IsComplete,
pub fn build(self) -> Documentwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn id(self, value: DocumentId) -> DocumentBuilder<SetId<S>>where
S::Id: IsUnset,
pub fn id(self, value: DocumentId) -> DocumentBuilder<SetId<S>>where
S::Id: IsUnset,
Required.
Source-backed id carried by this normalized pet-resort entity.
Sourcepub fn location_id(self, value: LocationId) -> DocumentBuilder<SetLocationId<S>>where
S::LocationId: IsUnset,
pub fn location_id(self, value: LocationId) -> DocumentBuilder<SetLocationId<S>>where
S::LocationId: IsUnset,
Required.
Source-backed location ID carried by this normalized pet-resort entity.
Sourcepub fn subject(self, value: DocumentSubject) -> DocumentBuilder<SetSubject<S>>where
S::Subject: IsUnset,
pub fn subject(self, value: DocumentSubject) -> DocumentBuilder<SetSubject<S>>where
S::Subject: IsUnset,
Required.
Source-backed subject carried by this normalized pet-resort entity.
Sourcepub fn classification(
self,
value: Classification,
) -> DocumentBuilder<SetClassification<S>>where
S::Classification: IsUnset,
pub fn classification(
self,
value: Classification,
) -> DocumentBuilder<SetClassification<S>>where
S::Classification: IsUnset,
Required.
Source-backed classification carried by this normalized pet-resort entity.
Sourcepub fn source(self, value: Source) -> DocumentBuilder<SetSource<S>>where
S::Source: IsUnset,
pub fn source(self, value: Source) -> DocumentBuilder<SetSource<S>>where
S::Source: IsUnset,
Required.
Source-backed source carried by this normalized pet-resort entity.
Sourcepub fn uploaded_by_actor(
self,
value: ActorRef,
) -> DocumentBuilder<SetUploadedByActor<S>>where
S::UploadedByActor: IsUnset,
pub fn uploaded_by_actor(
self,
value: ActorRef,
) -> DocumentBuilder<SetUploadedByActor<S>>where
S::UploadedByActor: IsUnset,
Required.
Source-backed uploaded by actor carried by this normalized pet-resort entity.
Sourcepub fn uploaded_at(
self,
value: DateTime<Utc>,
) -> DocumentBuilder<SetUploadedAt<S>>where
S::UploadedAt: IsUnset,
pub fn uploaded_at(
self,
value: DateTime<Utc>,
) -> DocumentBuilder<SetUploadedAt<S>>where
S::UploadedAt: IsUnset,
Required.
Source-backed uploaded at carried by this normalized pet-resort entity.
Sourcepub fn original_file(
self,
value: OriginalFile,
) -> DocumentBuilder<SetOriginalFile<S>>where
S::OriginalFile: IsUnset,
pub fn original_file(
self,
value: OriginalFile,
) -> DocumentBuilder<SetOriginalFile<S>>where
S::OriginalFile: IsUnset,
Required.
Source-backed original file carried by this normalized pet-resort entity.
Sourcepub fn storage_ref(self, value: StorageRef) -> DocumentBuilder<SetStorageRef<S>>where
S::StorageRef: IsUnset,
pub fn storage_ref(self, value: StorageRef) -> DocumentBuilder<SetStorageRef<S>>where
S::StorageRef: IsUnset,
Required.
Source-backed storage ref carried by this normalized pet-resort entity.
Sourcepub fn virus_scan_status(
self,
value: VirusScanStatus,
) -> DocumentBuilder<SetVirusScanStatus<S>>where
S::VirusScanStatus: IsUnset,
pub fn virus_scan_status(
self,
value: VirusScanStatus,
) -> DocumentBuilder<SetVirusScanStatus<S>>where
S::VirusScanStatus: IsUnset,
Required.
Source-backed virus scan status carried by this normalized pet-resort entity.
Sourcepub fn pii_redaction_status(
self,
value: PiiRedactionStatus,
) -> DocumentBuilder<SetPiiRedactionStatus<S>>where
S::PiiRedactionStatus: IsUnset,
pub fn pii_redaction_status(
self,
value: PiiRedactionStatus,
) -> DocumentBuilder<SetPiiRedactionStatus<S>>where
S::PiiRedactionStatus: IsUnset,
Required.
Source-backed pii redaction status carried by this normalized pet-resort entity.
Sourcepub fn verification_status(
self,
value: Status,
) -> DocumentBuilder<SetVerificationStatus<S>>where
S::VerificationStatus: IsUnset,
pub fn verification_status(
self,
value: Status,
) -> DocumentBuilder<SetVerificationStatus<S>>where
S::VerificationStatus: IsUnset,
Required.
Source-backed verification status carried by this normalized pet-resort entity.