IncidentBuilder

Struct IncidentBuilder 

pub struct IncidentBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> IncidentBuilder<S>

pub fn build(self) -> Incident
where S: IsComplete,

Finish building and return the requested object

pub fn id(self, value: IncidentId) -> IncidentBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

Source-backed id carried by this normalized pet-resort entity.

pub fn location_id(self, value: LocationId) -> IncidentBuilder<SetLocationId<S>>
where S::LocationId: IsUnset,

Required.

Source-backed location ID carried by this normalized pet-resort entity.

pub fn primary_subject( self, value: IncidentSubject, ) -> IncidentBuilder<SetPrimarySubject<S>>
where S::PrimarySubject: IsUnset,

Required.

Source-backed primary subject carried by this normalized pet-resort entity.

pub fn category(self, value: Category) -> IncidentBuilder<SetCategory<S>>
where S::Category: IsUnset,

Required.

Source-backed category carried by this normalized pet-resort entity.

pub fn severity(self, value: Severity) -> IncidentBuilder<SetSeverity<S>>
where S::Severity: IsUnset,

Required.

Source-backed severity carried by this normalized pet-resort entity.

pub fn status(self, value: Status) -> IncidentBuilder<SetStatus<S>>
where S::Status: IsUnset,

Required.

Source-backed status carried by this normalized pet-resort entity.

pub fn reported_by(self, value: ActorRef) -> IncidentBuilder<SetReportedBy<S>>
where S::ReportedBy: IsUnset,

Required.

Source-backed reported by carried by this normalized pet-resort entity.

pub fn reported_at( self, value: DateTime<Utc>, ) -> IncidentBuilder<SetReportedAt<S>>
where S::ReportedAt: IsUnset,

Required.

Source-backed reported at carried by this normalized pet-resort entity.

pub fn summary(self, value: Summary) -> IncidentBuilder<SetSummary<S>>
where S::Summary: IsUnset,

Required.

Source-backed summary carried by this normalized pet-resort entity.

pub fn required_review_gates( self, value: Vec<ReviewGate>, ) -> IncidentBuilder<SetRequiredReviewGates<S>>
where S::RequiredReviewGates: IsUnset,

Optional (Some / Option setters). Default: <Vec<policy::ReviewGate> as Default>::default().

Source-backed required review gates carried by this normalized pet-resort entity.

pub fn maybe_required_review_gates( self, value: Option<Vec<ReviewGate>>, ) -> IncidentBuilder<SetRequiredReviewGates<S>>
where S::RequiredReviewGates: IsUnset,

Optional (Some / Option setters). Default: <Vec<policy::ReviewGate> as Default>::default().

Source-backed required review gates carried by this normalized pet-resort entity.

pub fn audit_refs(self, value: Vec<EventId>) -> IncidentBuilder<SetAuditRefs<S>>
where S::AuditRefs: IsUnset,

Optional (Some / Option setters). Default: <Vec<crate::audit::EventId> as Default>::default().

Source-backed audit refs carried by this normalized pet-resort entity.

pub fn maybe_audit_refs( self, value: Option<Vec<EventId>>, ) -> IncidentBuilder<SetAuditRefs<S>>
where S::AuditRefs: IsUnset,

Optional (Some / Option setters). Default: <Vec<crate::audit::EventId> as Default>::default().

Source-backed audit refs carried by this normalized pet-resort entity.