pub struct Reservation {
pub id: Id,
pub location_id: LocationId,
pub customer_id: CustomerId,
pub pet_ids: Vec<PetId>,
pub service: ServiceKind,
pub status: Status,
pub starts_at: DateTime<Utc>,
pub ends_at: DateTime<Utc>,
pub deposit: Option<Deposit>,
pub source: Source,
pub requested_add_ons: Vec<AddOn>,
pub hard_stops: Vec<HardStop>,
}Expand description
Reservation record tying customer, pet, service, status, deposit, add-ons, and safety stops together.
Fields
id: IdSource-backed id carried by this normalized pet-resort entity.
location_id: LocationIdSource-backed location ID carried by this normalized pet-resort entity.
customer_id: CustomerIdSource-backed customer ID carried by this normalized pet-resort entity.
pet_ids: Vec<PetId>Source-backed pet IDs carried by this normalized pet-resort entity.
service: ServiceKindRequested service that drives scheduling and labor estimates.
status: StatusSource-backed status carried by this normalized pet-resort entity.
starts_at: DateTime<Utc>Source-backed starts at carried by this normalized pet-resort entity.
ends_at: DateTime<Utc>Source-backed ends at carried by this normalized pet-resort entity.
deposit: Option<Deposit>Source-backed deposit carried by this normalized pet-resort entity.
source: SourceSource-backed source carried by this normalized pet-resort entity.
requested_add_ons: Vec<AddOn>Source-backed requested add ons carried by this normalized pet-resort entity.
hard_stops: Vec<HardStop>Source-backed hard stops carried by this normalized pet-resort entity.
Implementations
Sourceimpl Reservation
impl Reservation
Sourcepub fn builder() -> ReservationBuilder
pub fn builder() -> ReservationBuilder
Create an instance of Reservation using the builder syntax